pub struct SuspendedResponse { /* private fields */ }Expand description
Contains suspended results. Can be turned into a byte stream with a prepended document.
Implementations
Sourceimpl SuspendedResponse
impl SuspendedResponse
Sourcepub fn into_stream(self, body: impl Into<Html>) -> HtmlStream
pub fn into_stream(self, body: impl Into<Html>) -> HtmlStream
Turns the SuspendedResponse into a stream for sending as a response.